@@ -13,6 +13,7 @@
 #
 #  The GPL3 license can be found at <http://www.gnu.org/licenses/>.
 #
+
 """
 Provides fitter functions.
 
@@ -29,8 +30,12 @@ from .source.ArctanModel import ArctanModel
 from .source.BSplinesModel import BSplinesModel
 from .source.BaseFitter import BaseFitter
 from .source.BaseModel import BaseModel
+#from .source.BernouilliErrorDistribution import BernouilliErrorDistribution 
 from .source.BirthEngine import BirthEngine
 from .source.BracketModel import BracketModel
+#from .source.CategoricalFitter import CategoricalFitter
+#from .source.CategoricalLikelihood import CategoricalLikelihood
+#from .source.CategoricalProblem import CategoricalProblem
 from .source.CauchyErrorDistribution import CauchyErrorDistribution
 from .source.CauchyPrior import CauchyPrior
 from .source.CircularUniformPrior import CircularUniformPrior
@@ -42,7 +47,9 @@ from .source.ConstantModel import ConstantModel
 from .source.ConvergenceError import ConvergenceError
 from .source.CrossEngine import CrossEngine
 from .source.CurveFitter import CurveFitter
+#from .source.CyclicResults import CyclicResults
 from .source.DeathEngine import DeathEngine
+from .source.DecisionTreeModel import DecisionTreeModel
 from .source.Dynamic import Dynamic
 from .source.Engine import Engine
 from .source.ErrorDistribution import ErrorDistribution
@@ -61,7 +68,6 @@ from .source.GalileanEngine import GalileanEngine
 from .source.GaussErrorDistribution import GaussErrorDistribution
 from .source.GaussModel import GaussModel
 from .source.GaussPrior import GaussPrior
-#from .source.GenGaussErrorDistribution import GenGaussErrorDistribution
 from .source.GibbsEngine import GibbsEngine
 from .source.HarmonicModel import HarmonicModel
 from .source.HarmonicDynamicModel import HarmonicDynamicModel
@@ -78,13 +84,17 @@ from .source.LaplacePrior import LaplacePrior
 from .source.LevenbergMarquardtFitter import LevenbergMarquardtFitter
 from .source.LinearModel import LinearModel
 from .source.LogFactorial import logFactorial
+from .source.LogisticModel import LogisticModel
 from .source.LorentzModel import LorentzModel
 from .source.MaxLikelihoodFitter import MaxLikelihoodFitter
 from .source.MixedErrorDistribution import MixedErrorDistribution
 from .source.Model import Model
+#from .source.ModelLikelihood import ModelLikelihood
+from .source.Modifiable import Modifiable
 from .source.MonteCarlo import MonteCarlo
 from .source.MultipleOutputProblem import MultipleOutputProblem
 from .source.NestedSampler import NestedSampler
+#from .source.NeuralNetModel import NeuralNetModel
 from .source.NoiseScale import NoiseScale
 from .source.NonLinearModel import NonLinearModel
 #from .source.OrderEngine import OrderEngine
@@ -108,6 +118,7 @@ from .source.RepeatingModel import RepeatingModel
 from .source.RobustShell import RobustShell
 from .source.Sample import Sample
 from .source.SampleList import SampleList
+from .source.SampleMovie import SampleMovie
 from .source.ScaledErrorDistribution import ScaledErrorDistribution
 ## import all fitters inside ScipyFitter
 from .source.ScipyFitter import *
@@ -121,6 +132,7 @@ from .source.SplinesModel import SplinesModel
 from .source.StartEngine import StartEngine
 from .source.StepEngine import StepEngine
 from .source.StellarOrbitModel import StellarOrbitModel
+from .source.StructureEngine import StructureEngine
 from .source.SurfaceSplinesModel import SurfaceSplinesModel
 from .source.UniformErrorDistribution import UniformErrorDistribution
 from .source.UniformPrior import UniformPrior
@@ -128,6 +140,20 @@ from .source.VoigtModel import VoigtModel
 from .source.Walker import Walker
 from .source.WalkerList import WalkerList
 
+## OrderProblems
+#from .source.DistanceCostFunction import DistanceCostFunction
+#from .source.NestedSolver import NestedSolver
+#from .source.LoopEngine import LoopEngine
+#from .source.MoveEngine import MoveEngine
+#from .source.OrderEngine import OrderEngine
+#from .source.OrderProblem import OrderProblem
+#from .source.ReverseEngine import ReverseEngine
+#from .source.SalesmanProblem import SalesmanProblem
+#from .source.ShuffleEngine import ShuffleEngine
+#from .source.StartNearEngine import StartNearEngine
+#from .source.StartOrderEngine import StartOrderEngine
+#from .source.SwitchEngine import SwitchEngine
+
 from .source.Formatter import formatter
 from .source.Formatter import fma
 from .source.Formatter import formatter_init
