@@ -1,5 +1,7 @@
 import numpy as numpy
 
+from . import Tools
+from .Formatter import formatter as fmt
 from .Dynamic import Dynamic
 from .Engine import Engine
 
@@ -92,15 +94,17 @@ class DeathEngine( Engine ):
         self.reportCall()
 
         cwalker = walker.copy()          ## work on local copy
-
         problem = cwalker.problem
         model = problem.model
-        ptry = cwalker.allpars
+        allp = cwalker.allpars
+        ptry = allp
         ftry = cwalker.fitIndex
 
-        pat = 0
+#        print( "DEAT0  ", fmt( ptry ), fmt( walker.problem.model.parameters ), fmt( ftry ) )
+
+        off = 0
         while model is not None and not isinstance( model, Dynamic ) :
-            pat += model.npbase
+            off += model.npbase
             model = model._next
 
         nc = model.ncomp
@@ -110,18 +114,19 @@ class DeathEngine( Engine ):
             print( "DEN1  ", cwalker.id, nc, np, len( ptry ), len( ftry ) )
 
         # shuffle the parameters (if needed) before throwing the last one out.
-        ptry = model.shuffle( ptry, pat, np, self.rng )
+        ptry = model.shuffle( ptry, off, np, self.rng )
 
         if not ( nc > model.growPrior.unit2Domain( self.rng.rand() ) and
-                model.shrink( pat ) ) :
-#            print( "DEN2  ", "failed" )
+                model.shrink( offset=off, rng=self.rng ) ) :
             self.reportFailed()
             return 0
 
         dnp = model.npbase - np         # parameter decrease
-        ptry = model.alterParameters( ptry, np, dnp, pat )
-        ftry = model.alterFitindex( ftry, np, dnp, pat )
-        problem.npars += dnp
+
+        ftry = model.alterFitindex( ftry, np, dnp, off )
+        ptry = problem.model.parameters
+        if self.errdis.nphypar > 0 :
+            ptry = numpy.append( ptry, allp[-self.errdis.nphypar:] )
 
         Ltry = self.errdis.logLikelihood( problem, ptry )
 
