@@ -33,7 +33,7 @@ __status__ = "Development"
 gllen = 120
 gindent = 0
 gmax = 5
-fmt = { "float64" : " %8.3f", "int64" : " %8d" }
+fmt = { "float64" : " %8.3f", "int64" : " %8d", "bool" : " %d" }
 
 
 def formatter_init( format={}, indent=None, linelength=None, max=-1 ):
