@@ -1,9 +1,7 @@
 import numpy as numpy
 import math
-import sys
 
 from .ScaledErrorDistribution import ScaledErrorDistribution
-from .NoiseScale import NoiseScale
 
 __author__ = "Do Kester"
 __year__ = 2018
@@ -27,11 +25,7 @@ __status__ = "Development"
 #  *
 #  * The GPL3 license can be found at <http://www.gnu.org/licenses/>.
 #  *
-#  * A JAVA version of this code was part of the Herschel Common
-#  * Science System (HCSS), also under GPL3.
-#  *
-#  *    2010 - 2014 Do Kester, SRON (Java code)
-#  *    2017        Do Kester
+#  *    2018        Do Kester
 
 
 class UniformErrorDistribution( ScaledErrorDistribution ):
@@ -40,7 +34,7 @@ class UniformErrorDistribution( ScaledErrorDistribution ):
 
     For one residual, x, it holds
     .. math::
-        f( x ) = 1 / s if abs( x ) < 2*s else 0
+        f( x ) = 1 / (2*s) if abs( x ) < s else 0
 
     where s is the scale.
     s is a hyperparameter, which might be estimated from the data.
@@ -51,13 +45,12 @@ class UniformErrorDistribution( ScaledErrorDistribution ):
     The function is mostly used to calculate the likelihood L, or easier
     to use log likelihood, logL.
     .. math::
-        logL = -log( s ) if abs( x ) < 2 * s else -inf
+        logL = -log( 2*s ) if abs( x ) < s else -inf
 
     Using weights this becomes:
     .. math::
-        logL = log( \sum( w ) / ( 2 s ) ) - \sum( w |x| / s  )
+        logL = -w * log( 2*s ) )
 
-    Using this error distribution results in median-like solutions.
 
     Author       Do Kester.
 
@@ -68,19 +61,12 @@ class UniformErrorDistribution( ScaledErrorDistribution ):
 
 
     #  *********CONSTRUCTORS***************************************************
-    def __init__( self, xdata, data, weights=None, scale=1.0, limits=None,
-                  copy=None ) :
+    def __init__( self, scale=1.0, limits=None, copy=None ) :
         """
         Constructor of Uniform Distribution.
 
         Parameters
         ----------
-        xdata : array_like
-            input data for the model
-        data : array_like
-            data to be fitted
-        weights : array_like
-            weights to be used
         scale : float
             noise scale
         limits : None or list of 2 floats [low,high]
@@ -92,12 +78,12 @@ class UniformErrorDistribution( ScaledErrorDistribution ):
         copy : UniformErrorDistribution
             distribution to be copied.
         """
-        super( UniformErrorDistribution, self ).__init__( xdata, data,
-               weights=weights, scale=scale, limits=limits, copy=copy )
+        super( UniformErrorDistribution, self ).__init__( scale=scale,
+                limits=limits, copy=copy )
 
     def copy( self ):
         """ Return copy of this.  """
-        return UniformErrorDistribution( self.xdata, self.data, copy=self )
+        return UniformErrorDistribution( copy=self )
 
     #  *********DATA & WEIGHT***************************************************
     def acceptWeight( self ):
@@ -107,6 +93,21 @@ class UniformErrorDistribution( ScaledErrorDistribution ):
         """
         return True
 
+    def getScale( self, problem, allpars=None ) :
+        """
+        Return the noise scale
+
+        Parameters
+        ----------
+        problem : Problem
+            to be solved
+        allpars : array_like
+            None take parameters from problem.model
+            list of all parameters in the problem
+        """
+        res = self.getResiduals( problem, allpars=allpars )
+        return numpy.max( numpy.abs( res ) )
+
     def toSigma( self, scale ) :
         """
         Return sigma, the squareroot of the variance.
@@ -118,50 +119,69 @@ class UniformErrorDistribution( ScaledErrorDistribution ):
         return scale * 2 / math.sqrt( 12 )
 
     #  *********LIKELIHOODS***************************************************
-    def logLikelihood( self, model, allpars ) :
+    def logLikelihood_alt( self, problem, allpars ) :
         """
-        Return the log( likelihood ) for a Gaussian distribution.
+        Return the log( likelihood ) for a Uniform distribution.
+
+        Alternate calculation.
 
         Outside the range the likelihood is zero, so the logL should be -inf.
         However for computational reasons the maximum negative value is returned.
 
         Parameters
         ----------
-        model : Model
-            model to calculate mock data
+        problem : Problem
+            to be solved
         allpars : array_like
             parameters of the problem
 
         """
         self.ncalls += 1
-        np = model.npchain
+
         scale = allpars[-1]
-        ares = numpy.abs( self.getResiduals( model, allpars[:np] ) )
+
+        ares = numpy.abs( problem.residuals( allpars[:-1] ) )
 
         if all( ares < scale ) :
-            return - math.log( 2 * scale ) * self.sumweight
+            return - math.log( 2 * scale ) * problem.sumweight
 
-        return -sys.float_info.max
+        return -math.inf
 
-    def getScale( self, model ) :
+    def logLdata( self, problem, allpars, mockdata=None ) :
         """
-        Return the noise scale
+        Return the log( likelihood ) for each residual
+
+        logL = sum( logLdata )
 
         Parameters
         ----------
-        model : Model
-            the model involved
-        """
-        return numpy.max( numpy.abs( self.getResiduals( model ) ) )
+        problem : Problem
+            to be solved
+        allpars : array_like
+            list of all parameters in the problem
+        mockdata : array_like
+            as calculated by the model
 
-    def partialLogL( self, model, allpars, fitIndex ) :
+        """
+        if mockdata is None :
+            mockdata = problem.result( allpars[:-1] )
+        scale = allpars[-1]
+        ares = numpy.abs( problem.ydata - mockdata )
+
+        lld = numpy.where( ares < scale, -math.log( 2 * scale ), -math.inf )
+        if problem.weights is not None :
+            lld *= problem.weights
+        return lld
+
+
+    def partialLogL_alt( self, problem, allpars, fitIndex ) :
         """
         Return the partial derivative of log( likelihood ) to the parameters.
 
         Parameters
         ----------
-        model : Model
-            model to calculate mock data
+        problem : Problem
+            to be solved
         allpars : array_like
             parameters of the problem
         fitIndex : array_like
@@ -170,9 +190,41 @@ class UniformErrorDistribution( ScaledErrorDistribution ):
         """
         dL = numpy.zeros( len( fitIndex ), dtype=float )
         if fitIndex[-1] == -1 :
-            dL[-1] = -self.sumweight / allpars[-1]
+            dL[-1] = -problem.sumweight / allpars[-1]
         return dL
 
+    def nextPartialData( self, problem, allpars, fitIndex, mockdata=None ) :
+        """
+        Return the partial derivative of elements of the log( likelihood )
+        to the parameters.
+
+        Parameters
+        ----------
+        problem : Problem
+            to be solved
+        allpars : array_like
+            parameters of the problem
+        fitIndex : array_like
+            indices of parameters to be fitted
+        mockdata : array_like
+            as calculated by the model
+
+        """
+        scale = allpars[-1]
+        pll = numpy.zeros_like( problem.ydata )
+        if problem.weights is not None :
+            wgt = problem.weights
+        else :
+            wgt = numpy.ones_like( problem.ydata )
+
+        for k in fitIndex :
+            if k >= 0 :
+                yield pll
+            else :
+                yield ( - wgt / scale )
+
+        return
+
     def __str__( self ) :
         return "Uniform error distribution"
 
